import { Query, Mutation } from "./w3";
import * as Types from "./w3";
import { Address, AccountIndex, EthereumSigner, EthereumProvider, Connection, ConnectionConfig, ConnectionConfigs } from "./Connection";
import { Client, Plugin, PluginPackageManifest, PluginFactory } from "@web3api/core-js";
export { Address, AccountIndex, EthereumSigner, EthereumProvider, ConnectionConfig, ConnectionConfigs, };
export interface EthereumConfig {
    networks: ConnectionConfigs;
    defaultNetwork?: string;
}
export declare class EthereumPlugin extends Plugin {
    private _connections;
    private _defaultNetwork;
    constructor(config: EthereumConfig);
    static manifest(): PluginPackageManifest;
    getModules(_client: Client): {
        query: Query.Module;
        mutation: Mutation.Module;
    };
    callContractMethod(input: Mutation.Input_callContractMethod): Promise<Types.TxResponse>;
    callContractMethodAndWait(input: Mutation.Input_callContractMethodAndWait): Promise<Types.TxReceipt>;
    sendTransaction(input: Mutation.Input_sendTransaction): Promise<Types.TxResponse>;
    sendTransactionAndWait(input: Mutation.Input_sendTransactionAndWait): Promise<Types.TxReceipt>;
    deployContract(input: Mutation.Input_deployContract): Promise<string>;
    signMessage(input: Mutation.Input_signMessage): Promise<string>;
    sendRPC(input: Mutation.Input_sendRPC): Promise<string>;
    callContractView(input: Query.Input_callContractView): Promise<string>;
    callContractStatic(input: Query.Input_callContractStatic): Promise<Types.StaticTxResult>;
    encodeParams(input: Query.Input_encodeParams): string;
    getSignerAddress(input: Query.Input_getSignerAddress): Promise<string>;
    getSignerBalance(input: Query.Input_getSignerBalance): Promise<string>;
    getSignerTransactionCount(input: Query.Input_getSignerTransactionCount): Promise<string>;
    getGasPrice(input: Query.Input_getGasPrice): Promise<string>;
    estimateTransactionGas(input: Query.Input_estimateTransactionGas): Promise<string>;
    estimateContractCallGas(input: Query.Input_estimateContractCallGas): Promise<string>;
    checkAddress(input: Query.Input_checkAddress): boolean;
    toWei(input: Query.Input_toWei): string;
    toEth(input: Query.Input_toEth): string;
    waitForEvent(input: Query.Input_waitForEvent): Promise<Types.EventNotification>;
    awaitTransaction(input: Query.Input_awaitTransaction): Promise<Types.TxReceipt>;
    getConnection(connection?: Types.Connection | null): Promise<Connection>;
    parseArgs(args?: string[] | null): unknown[];
    private _callContractMethod;
}
export declare const ethereumPlugin: PluginFactory<EthereumConfig>;
export declare const plugin: PluginFactory<EthereumConfig>;
